use log::LevelFilter;
use raylib::prelude::*;

mod player;
mod world;
mod renderer;

pub const VEL: f32 = 20000.0;

fn main() {
    env_logger::builder()
        .filter_level(LevelFilter::Trace)
        .init();
    let mut rend = renderer::Renderer::init();
    
    let surface_level = 16; 

    let mut world = world::World::new();
    world.generate_new(surface_level);
    
    let mut player = player::Player::new((0.0, (surface_level+1) as f32).into());

    log::info!("Started up!");
    while !rend.should_close() {
        let dt = rend.get_delta_time() / 1000.0;
        if rend.raylib.0.is_key_down(KeyboardKey::KEY_A) {
            player.vel.x = VEL;
        }
        if rend.raylib.0.is_key_down(KeyboardKey::KEY_D) {
            player.vel.x = -VEL;
        }

        if rend.raylib.0.is_key_down(KeyboardKey::KEY_SPACE) && world.is_on_ground(player.pos){
            player.vel.y = VEL;
        }
        
        player.calc_phisics(&world, dt);
        
        // log::debug!("VEL: {:?}", player.vel);

        rend.draw_world(&world, &player);
    }
}
