use std::collections::HashMap;

use raylib::math::Vector2;

use self::chunk::{Chunk, CHUNK_WIDTH};


pub mod chunk;
mod entity;
mod block;
pub mod id;

pub struct World {
    chunks: HashMap<isize, chunk::Chunk>,
    entities: Vec<entity::Entity>
}


impl World {
    pub fn new() -> Self {
        Self {
            chunks: HashMap::new(),
            entities: Vec::new()
        }
    }

    pub fn generate_new(&mut self, surface_level: u8) {
        self.chunks.clear();
        self.entities.clear();
        for i in -2..=2 {
            self.chunks.insert(i, Chunk::new_flat(surface_level));
        }
    }

    pub fn is_on_ground(&self, pos: Vector2) -> bool {
        let chunk_id = pos.x / CHUNK_WIDTH as f32;
        let rel_pos_x = pos.x % CHUNK_WIDTH as f32;

        let Some(chunk) = self.chunks().get(&(chunk_id as isize)) else {
            return false;
        };
        
        let Some(((_, by), _)) = chunk.blocks().get_key_value(&(rel_pos_x as u8, pos.y as u8)) else {
            return false;
        };
        
        log::debug!("by: {}, py: {}", by, pos.y);

        *by as u8 == pos.y as u8 
    }

    pub fn chunks(&self) -> &HashMap<isize, chunk::Chunk> {
        &self.chunks
    }

    pub fn chunks_mut(&mut self) -> &mut HashMap<isize, chunk::Chunk> {
        &mut self.chunks
    }
}
